<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="rowSelection"
      @change="handleTableChange"
    >
    </a-table>
  </a-card>
</template>

<script>
import { requestPut,getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: 'InboundApplyDetailList',
  mixins: [JeecgListMixin],
  components: {},
  data() {
    return {
      url: {
        list: '/tms/inboundDetail/list',
      },
      queryParam: {},
      nodeType: 0,
      dataSource: [],
      disableMixinCreated:true,
      columns: [
        {
          title: '工具编码',
          align: 'center',
          dataIndex: 'toolCode',
          width: '10%',
          key: 'toolCode'
        },
        {
          title: '工具名称',
          dataIndex: 'chineseName',
          align: 'center',
          key: 'toolName'
        },
        {
          title: '型号/图号',
          dataIndex: 'toolModel',
          align: 'center',
          key: 'toolModel'
        },
      
        {
          title: '工具分类',
          dataIndex: 'applicationType',
          align: 'center',
        },
         {
          title: '入库数量',
          dataIndex: 'inStorageQuantity',
          align: 'center',
        },
        {
          title: '实际入库数量',
          dataIndex: 'inActualCount',
          align: 'center',
        }
      ]
    }
  },

  computed: {
    rowSelection() {
      return {
        type: 'checkbox',
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys
          this.onSelectChange(selectedRowKeys,selectedRows)
        },
        getCheckboxProps: (record) => ({
          props: {
            disabled: record.distable,
          },
        }),
        selectedRowKeys: this.selectedRowKeys,
      }
    },
  },

  methods: {
    loadData(arg) {
        if(!this.url.list){
          this.$message.error("请设置url.list属性!")
          return
        }
        //加载数据 若传入参数1则加载第一页的内容
        if (arg === 1) {
          this.ipagination.current = 1;
        }
        var params = this.getQueryParams();//查询条件
        this.loading = true;
        getAction(this.url.list, params).then((res) => {
          if (res.success) {
            for (let i = 0; i < res.result.records.length; i++) {
            if (res.result.records[i].inStorageQuantity == res.result.records[i].inActualCount) {
              res.result.records[i].distable = true
            } else {
              res.result.records[i].distable = false
            }
          }
            this.dataSource = res.result.records;
            this.ipagination.total = res.result.total;
          }
          if(res.code===510){
            this.$message.warning(res.message)
          }
          this.loading = false;
        })
      },
    onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;
        this.$emit('selectRows', selectionRows)
      },

  },
  mounted() {
    this.$bus.$on('getToolingStorageData', (data) => {
      this.queryParam.inboundOrderId = data.id;
      this.searchQuery();
    })
  }
}
</script>

<style scoped>
@import '~@assets/less/common.less';
</style>